@@ -34,4 +34,8 @@ public interface MultiGridView<T extends GenericSummary, V> extends ListView<T,
                        Consumer<ListTable<T>> callback);
 
     void setSaveFilterCallback(BiConsumer<String, Consumer<String>> filterNameCallback);
-}
\ No newline at end of file
+
+    String getSortColumn();
+    
+    Boolean isSortAscending();
+}
